
%global javacup_or_asm java_cup:java_cup|org\\.ow2\\.asm:asm.*
%global mvn_javacup_or_asm_matcher .*mvn\\(%{javacup_or_asm}\\)
%global __requires_exclude ^%{mvn_javacup_or_asm_matcher}

Summary:          Simplify Java tracing, monitoring and testing with Byteman
Name:             byteman
Version:          4.0.19
Release:          6%{?dist}
License:          LGPLv2+
URL:              http://www.jboss.org/byteman
Source0:          https://github.com/bytemanproject/byteman/archive/%{version}.tar.gz

Patch3001:        remove_submit_integration_test_verification.patch
Patch3002:        testng7_port.patch

BuildRequires:    java-11-openjdk-devel maven-local maven-shade-plugin maven-source-plugin
BuildRequires:    maven-plugin-plugin maven-plugin-bundle maven-assembly-plugin maven-failsafe-plugin
BuildRequires:    maven-jar-plugin maven-surefire-plugin maven-surefire-provider-testng maven-dependency-plugin
BuildRequires:    maven-surefire-provider-junit maven-surefire-provider-junit5 maven-verifier-plugin 
BuildRequires:    java_cup objectweb-asm junit junit5 testng jdependency
Provides:         bundled(objectweb-asm) = 9.1
Provides:         bundled(java_cup) = 0.11b-17
Requires:         java-headless

BuildArch:        noarch
ExclusiveArch:    %{java_arches} noarch

%description
Byteman is a tool which makes it easy to trace, monitor and test
the behaviour of Java application and JDK runtime code. It injects
Java code into your application methods or into Java runtime methods
without the need for you to recompile, repackage or even redeploy
your application. Injection can be performed at JVM startup or after
startup while the application is still running. Injected code can
access any of your data and call any application methods, including
where they are private. You can inject code almost anywhere you want
and there is no need to prepare the original source code in advance.
You can even remove injected code and reinstall different changes
while the application continues to execute.

%package javadoc
Summary:          Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%package rulecheck-maven-plugin
Summary:          Maven plugin for checking Byteman rules.

%description rulecheck-maven-plugin
This package contains the Byteman rule check maven plugin.

%package bmunit
Summary:          TestNG and JUnit integration for Byteman.

%description bmunit
The Byteman bmunit jar provides integration of Byteman into
TestNG and JUnit tests.

%package dtest
Summary:          Remote byteman instrumented testing.

%description dtest
The Byteman dtest jar supports instrumentation of test code executed on
remote server hosts and validation of assertions describing the expected
operation of the instrumented methods.

%prep
%autosetup -n byteman-%{version} -p2

sed -i "s|net.sf.squirrel-sql.thirdparty-non-maven|java_cup|" agent/pom.xml
sed -i "s|java-cup|java_cup|" agent/pom.xml
sed -i "s|net.sf.squirrel-sql.thirdparty-non-maven|java_cup|" tests/pom.xml
sed -i "s|java-cup|java_cup|" tests/pom.xml

%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-failsafe-plugin']/pom:executions/pom:execution[pom:id='submit.TestSubmit']" agent
%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-failsafe-plugin']/pom:executions/pom:execution[pom:id='submit.TestSubmit.compiled']" agent

%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-failsafe-plugin']/pom:executions/pom:execution[pom:id='submit.TestSubmit']" tests
%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-failsafe-plugin']/pom:executions/pom:execution[pom:id='submit.TestSubmit.compiled']" tests

%pom_xpath_remove "pom:profiles/pom:profile/pom:dependencies/pom:dependency[pom:artifactId='tools']/pom:scope" install
%pom_xpath_remove "pom:profiles/pom:profile/pom:dependencies/pom:dependency[pom:artifactId='tools']/pom:systemPath" install
%pom_xpath_remove "pom:profiles/pom:profile/pom:dependencies/pom:dependency[pom:artifactId='tools']/pom:scope" contrib/bmunit
%pom_xpath_remove "pom:profiles/pom:profile/pom:dependencies/pom:dependency[pom:artifactId='tools']/pom:systemPath" contrib/bmunit

%pom_xpath_remove "pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-surefire-plugin']/pom:executions" contrib/bmunit
%pom_xpath_set "pom:build/pom:plugins/pom:plugin[pom:artifactId='maven-surefire-plugin']/pom:configuration" '<skip>true</skip>' contrib/bmunit

%pom_disable_module download
%pom_disable_module docs

%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_dep 'org.apache.maven:maven-project' contrib/rulecheck-maven-plugin
%pom_xpath_remove 'pom:execution[pom:id="make-javadoc-assembly"]' byteman

%mvn_package ":byteman-rulecheck-maven-plugin" rulecheck-maven-plugin

%pom_add_dep "org.apache.commons:commons-lang3" contrib/bmunit5
%mvn_package ":byteman-bmunit" bmunit
%mvn_package ":byteman-dtest" dtest

%build
export JAVA_HOME=/usr/lib/jvm/java-11
%mvn_build

%install
%mvn_install
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -d -m 755 %{buildroot}%{_datadir}/%{name}/lib
install -d -m 755 %{buildroot}%{_datadir}/%{name}/bin
install -m 755 bin/bmsubmit.sh %{buildroot}%{_datadir}/%{name}/bin/bmsubmit
install -m 755 bin/bminstall.sh  %{buildroot}%{_datadir}/%{name}/bin/bminstall
install -m 755 bin/bmjava.sh  %{buildroot}%{_datadir}/%{name}/bin/bmjava
install -m 755 bin/bmcheck.sh  %{buildroot}%{_datadir}/%{name}/bin/bmcheck

for f in bmsubmit bmjava bminstall bmcheck; do
cat > %{buildroot}%{_bindir}/${f} << EOF
#!/bin/sh

export BYTEMAN_HOME=/usr/share/byteman
export JAVA_HOME=/usr/lib/jvm/java

\$BYTEMAN_HOME/bin/${f} \$*
EOF
done

chmod 755 %{buildroot}%{_bindir}/*

for m in bmunit dtest install sample submit; do
  ln -s %{_javadir}/byteman/byteman-${m}.jar %{buildroot}%{_datadir}/%{name}/lib/byteman-${m}.jar
done

install -d -m 755 %{buildroot}%{_datadir}/%{name}/contrib
install -d -m 755 %{buildroot}%{_datadir}/%{name}/contrib/jboss-modules-system
ln -s %{_javadir}/byteman/byteman-jboss-modules-plugin.jar %{buildroot}%{_datadir}/%{name}/contrib/jboss-modules-system/byteman-jboss-modules-plugin.jar
ln -s %{_javadir}/byteman/byteman.jar %{buildroot}%{_datadir}/%{name}/lib/byteman.jar

%files -f .mfiles
%license docs/copyright.txt
%doc README
%{_datadir}/%{name}/lib/byteman.jar
%{_datadir}/%{name}/lib/byteman-install.jar
%{_datadir}/%{name}/lib/byteman-sample.jar
%{_datadir}/%{name}/lib/byteman-submit.jar
%{_datadir}/%{name}/contrib/*
%{_datadir}/%{name}/bin/*
%{_bindir}/*

%files javadoc -f .mfiles-javadoc
%license docs/copyright.txt

%files rulecheck-maven-plugin -f .mfiles-rulecheck-maven-plugin
%license docs/copyright.txt

%files bmunit -f .mfiles-bmunit
%license docs/copyright.txt
%{_datadir}/%{name}/lib/byteman-bmunit.jar

%files dtest -f .mfiles-dtest
%license docs/copyright.txt
%{_datadir}/%{name}/lib/byteman-dtest.jar

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.19-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.19-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.19-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.0.19-3
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 26 2023 Miaojun Dong <zoedong@tencent.com> - 4.0.19-2
- modified to conform to the spec format specification

* Wed Apr 26 2023 Miaojun Dong <zoedong@tencent.com> - 4.0.19-1
- initial build
